netapp_ontap.models.lun_space API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.lun_space`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class LunSpaceSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the LunSpace object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `guarantee GET POST PATCH`

    The guarantee field of the lun_space.

  `size GET POST PATCH`

    The total provisioned size of the LUN. The LUN size can be increased but not be made smaller using the REST interface.
    The maximum and minimum sizes listed here are the absolute maximum and absolute minimum sizes in bytes. The actual minimum and maxiumum sizes vary depending on the ONTAP version, ONTAP platform and the available space in the containing volume and aggregate. For more information, see Size properties in the docs section of the ONTAP REST API documentation.

    Example: 1073741824

  `used GET`

    The amount of space consumed by the main data stream of the LUN.
    This value is the total space consumed in the volume by the LUN, including filesystem overhead, but excluding prefix and suffix streams. Due to internal filesystem overhead and the many ways SAN filesystems and applications utilize blocks within a LUN, this value does not necessarily reflect actual consumption/availability from the perspective of the filesystem or application. Without specific knowledge of how the LUN blocks are utilized outside of ONTAP, this property should not be used as an indicator for an out-of-space condition.
    For more information, see Size properties in the docs section of the ONTAP REST API documentation.